package edu.fu_tdg.lodib.mapping.sparql.factory;

import edu.fu_tdg.lodib.mapping.DataTranslationMapping;
import edu.fu_tdg.lodib.mapping.InputDataTranslationMapping;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.AddLangTagMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.AggregationMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.ChangeDatatypeMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.DeresourcifyMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.NToOneMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.OneToOneMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.RemoveLangTagMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.RenameClassBasedOnPropertyMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.RenameClassBasedOnValueMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.RenameClassMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.RenamePropertyMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.ResourcifyMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.ReversePropertyMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.URIToValueMappingJena;
import edu.fu_tdg.lodib.mapping.sparql.factory.jena.ValueToURIMappingJena;

public class MappingFactory {
	public static DataTranslationMapping createMapping(MappingType mappingType, TechnologyType technology, InputDataTranslationMapping object) {
		DataTranslationMapping ret = null;
		
		// If we are working with Jena
		switch (technology) {
			case JENA:
				// We check all types of mappings
				switch (mappingType) {
					case RENAME_CLASS:
						ret = new RenameClassMappingJena(object);
						break;
					case RENAME_PROPERTY:
						ret = new RenamePropertyMappingJena(object);
						break;
					case RENAME_CLASS_BASED_ON_PROPERTY:
						ret = new RenameClassBasedOnPropertyMappingJena(object);
						break;
					case RENAME_CLASS_BASED_ON_VALUE:
						ret = new RenameClassBasedOnValueMappingJena(object);
						break;
					case REVERSE_PROPERTY:
						ret = new ReversePropertyMappingJena(object);
						break;
					case RESOURCIFY:
						ret = new ResourcifyMappingJena(object);
						break;
					case DERESOURCIFY:
						ret = new DeresourcifyMappingJena(object);
						break;
					case ONE_TO_ONE:
						ret = new OneToOneMappingJena(object);
						break;
					case URI_TO_VALUE:
						ret = new URIToValueMappingJena(object);
						break;
					case VALUE_TO_URI:
						ret = new ValueToURIMappingJena(object);
						break;
					case CHANGE_DATATYPE:
						ret = new ChangeDatatypeMappingJena(object);
						break;
					case ADD_LANG_TAG:
						ret = new AddLangTagMappingJena(object);
						break;
					case REMOVE_LANG_TAG:
						ret = new RemoveLangTagMappingJena(object);
						break;
					case N_TO_ONE:
						ret = new NToOneMappingJena(object);
						break;
					case AGGREGATION:
						ret = new AggregationMappingJena(object);
						break;
					default:
						break;
				}
				break;
			default:
				break;
		}
		
		return ret;
	}
}
