package edu.fu_tdg.lodib.rdf_generator.literal;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.Random;
import java.util.UUID;

import edu.fu_tdg.lodib.rdf_generator.distributions.Distribution;
import edu.fu_tdg.lodib.rdf_generator.distributions.UniformDistribution;
import edu.fu_tdg.lodib.utils.Utils;

public class StringGenerator implements LiteralGenerator {
    private static Random rand = new Random(808080L);
	private Integer minWords, maxWords;
	private String type;
	private String langTag;
	private Map<String, String> namespaces;
	private List<String> values;
	
	public StringGenerator(Integer minWords, Integer maxWords, String type, String langTag, String values, Map<String, String> namespaces) {
		this.minWords = minWords;
		this.maxWords = maxWords;
		this.type = type;
		this.langTag = langTag;
		this.namespaces = namespaces;
		if (values != null)
			this.values = Arrays.asList(values.split(Utils.COMMA));
	}

	public String generateValue() {
		long min = minWords.longValue();
		long max = maxWords.longValue() + 1;
		
		// TODO 2: This distribution should be configurable
		Distribution<Long> dist = new UniformDistribution<Long>(min, max);
		Long number = dist.getValue();
		
		// Create string
		StringBuffer buf = new StringBuffer();
		for (int i = 0; i < number; i++) {
			buf.append(createWord());
			if (i != number - 1)
				buf.append(Utils.SPACE);
		}
		
		return (langTag == null) ? Utils.createLiteralType(buf.toString(), type, namespaces) : Utils.createLiteralLang(buf.toString(), langTag);
	}
	
	private String createWord() {
		String ret = null;

		if (values == null)
	        ret = createRandomWord();
		else
			ret = values.get(rand.nextInt(values.size()));

		return ret;
	}

    private static String createRandomWord() {
        int length = rand.nextInt(6)+2;
        byte[] word = new byte[length];
        rand.nextBytes(word);
        StringBuffer sb = new StringBuffer();
        for(byte b: word) {
          char  c = (char)((int)(Math.abs(b) % 26)+'a');
          sb.append(c);
        }
        return sb.toString();
    }
}
