package edu.fu_tdg.lodib.test;

import com.hp.hpl.jena.ontology.OntModel;
import com.hp.hpl.jena.ontology.OntModelSpec;
import com.hp.hpl.jena.query.Dataset;
import com.hp.hpl.jena.query.Query;
import com.hp.hpl.jena.query.QueryExecutionFactory;
import com.hp.hpl.jena.query.Syntax;
import com.hp.hpl.jena.rdf.model.ModelFactory;
import edu.fu_tdg.lodib.utils.Utils;
import edu.fu_tdg.lodib.validator.DataLoader;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.Collection;
import java.util.Properties;
import java.util.Set;

/**
 * Created by IntelliJ IDEA.
 * User: andreas
 * Date: 3/19/12
 * Time: 11:51 AM
 * To change this template use File | Settings | File Templates.
 */
public class TranslatorJena1_1OnTDBDataset {
    public static final String SOURCE_1_FILE = "file.source1";
	public static final String TARGET_1_FILE = "file.target1";
	public static final String SOURCE_2_FILE = "file.source2";
	public static final String TARGET_2_FILE = "file.target2";
	public static final String SOURCE_3_FILE = "file.source3";
	public static final String TARGET_3_FILE = "file.target3";
	public static final String MAPPING_1_FILE = "mapping.source1";
	public static final String MAPPING_2_FILE = "mapping.source2";
	public static final String MAPPING_3_FILE = "mapping.source3";

	public static String CONFIG = "conf/jena1.1-config.properties";

	/**
	 * @param args
	 * @throws edu.fu_tdg.lodib.rdf_generator.RDFGeneratorException
	 */
	public static void main(String[] args) throws Exception {
        if(args.length>0) {
            System.out.println("Using config file: " + args[0]);
            CONFIG = args[0];
        }

		Properties properties = new Properties();
		properties.load(new FileInputStream(CONFIG));
        Long startTime = System.currentTimeMillis();
		performDataTranslation(properties.getProperty(SOURCE_1_FILE), properties.getProperty(TARGET_1_FILE), properties.getProperty(MAPPING_1_FILE));
        System.out.println("Translation of source 1 took: " + (System.currentTimeMillis()-startTime)/1000.0 + "s");
        Long startTime2 = System.currentTimeMillis();
		performDataTranslation(properties.getProperty(SOURCE_2_FILE), properties.getProperty(TARGET_2_FILE), properties.getProperty(MAPPING_2_FILE));
        System.out.println("Translation of source 2 took: " + (System.currentTimeMillis()-startTime2)/1000.0 + "s");
        Long startTime3 = System.currentTimeMillis();
		performDataTranslation(properties.getProperty(SOURCE_3_FILE), properties.getProperty(TARGET_3_FILE), properties.getProperty(MAPPING_3_FILE));
        System.out.println("Translation of source 3 took: " + (System.currentTimeMillis()-startTime3)/1000.0 + "s");
        System.out.println("Translation of all sources took: " + (System.currentTimeMillis()-startTime)/1000.0 + "s");
	}

	private static void performDataTranslation(String sourceFile, String targetFile, String queriesFile) throws Exception {
		Dataset source = DataLoader.openDataset(sourceFile);

		OntModel target = ModelFactory.createOntologyModel(OntModelSpec.OWL_MEM, DataLoader.createTmpTDBModel());

		Set<Query> queries = Utils.parseJenaSPARQLQueries(queriesFile, Syntax.syntaxSPARQL_11);

		performDataTranslation(source, target, queries);

		target.write(new FileOutputStream(new File(targetFile)), Utils.N_TRIPLE);
	}

	private static void performDataTranslation(OntModel source, OntModel target, Collection<Query> mappings) {
		for (Query m : mappings)
			QueryExecutionFactory.create(m, source).execConstruct(target);
	}

    private static void performDataTranslation(Dataset source, OntModel target, Collection<Query> mappings) {
        for (Query m : mappings)
			QueryExecutionFactory.create(m, source).execConstruct(target);
    }
}
